@@ -8,7 +8,7 @@
 
 BEGIN { $| = 1; print "1..1\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use Unix::Passwd;
+use Passwd::Unix;
 $loaded = 1;
 print "ok 1\n";
 
